@@ -113,7 +113,7 @@ func (r *MigPlan) GetDestinationCluster(client k8sclient.Client) (*MigCluster, e
 	return GetCluster(client, r.Spec.DestMigClusterRef)
 }
 
-// GetStorage - Get the referenced storage..
+// GetStorage - Get the referenced storage.
 // Returns `nil` when the reference cannot be resolved.
 func (r *MigPlan) GetStorage(client k8sclient.Client) (*MigStorage, error) {
 	return GetStorage(client, r.Spec.MigStorageRef)
@@ -701,6 +701,7 @@ func (r *MigPlan) HasConflict(plan *MigPlan) bool {
 const (
 	PvMoveAction = "move"
 	PvCopyAction = "copy"
+	PvSkipAction = "skip"
 )
 
 // PV Copy Methods.
@@ -730,9 +731,10 @@ type PV struct {
 
 // PVC
 type PVC struct {
-	Namespace   string                            `json:"namespace,omitempty" protobuf:"bytes,3,opt,name=namespace"`
-	Name        string                            `json:"name,omitempty" protobuf:"bytes,1,opt,name=name"`
-	AccessModes []kapi.PersistentVolumeAccessMode `json:"accessModes,omitempty" protobuf:"bytes,1,rep,name=accessModes,casttype=PersistentVolumeAccessMode"`
+	Namespace    string                            `json:"namespace,omitempty" protobuf:"bytes,3,opt,name=namespace"`
+	Name         string                            `json:"name,omitempty" protobuf:"bytes,1,opt,name=name"`
+	AccessModes  []kapi.PersistentVolumeAccessMode `json:"accessModes,omitempty" protobuf:"bytes,1,rep,name=accessModes,casttype=PersistentVolumeAccessMode"`
+	HasReference bool                              `json:"hasReference,omitempty"`
 }
 
 // Supported
@@ -744,7 +746,7 @@ type Supported struct {
 }
 
 // Selection
-// Action - The PV migration action (move|copy)
+// Action - The PV migration action (move|copy|skip)
 // StorageClass - The PV storage class name to use in the destination cluster.
 // AccessMode   - The PV access mode to use in the destination cluster, if different from src PVC AccessMode
 // CopyMethod   - The PV copy method to use ('filesystem' for restic copy, or 'snapshot' for velero snapshot plugin)
